# Mastering the Lightning Network
[![Build Status](https://travis-ci.com/lnbook/lnbook.svg?branch=develop)](https://travis-ci.com/lnbook/lnbook)

STATUS: First Edition published on Dec 21, 2021

<img src="images/cover_thumb.png" width=200 alt="Mastering Lightning Cover">

## About
Mastering the Lightning Network is an O'Reilly Media book, by authors Andreas M. Antonopoulos ([@aantonop](https://twitter.com/aantonop)), Olaoluwa Osuntokun ([@roasbeef](https://twitter.com/roasbeef)), Rene Pickhardt ([@renepickhardt](https://twitter.com/renepickhardt)). It was published on Dec 21, 2021, in paperback and e-book, by O'Reilly Media. It is available everywhere that books are sold. This repository contains the manuscript of the book as published by O'Reilly Media, tagged as [firstedition_firstprint](https://github.com/lnbook/lnbook/releases/tag/firstedition_firstprint).

The book describes the Lightning Network (LN), a Peer-to-Peer protocol running on top of Bitcoin and other blockchains, which provides near-instant, secure, micro-payments.

The book is suitable for technical readers with an understanding of the fundamentals of Bitcoin and other open blockchains.

## Contents

### Preface

*  [Cover](cover.html)
*  [Titlepage](titlepage.html)
*  [Copyright](copyright.html)
*  [Table of Contents](toc.html)
*  [Preface](preface.asciidoc)

### Part 1

*  [Part 1 - Intro](part_1_divider.asciidoc)
*  [Introduction](01_introduction.asciidoc)
*  [Getting Started](02_getting_started.asciidoc)
*  [How the Lightning Network Works](03_how_ln_works.asciidoc)
*  [Lightning Node Software](04_node_client.asciidoc)
*  [Operating a Lightning Network Node](05_node_operations.asciidoc)

### Part 2

*  [Part 2 - Intro](part_2_divider.asciidoc)
*  [Lightning Network Architecture](06_lightning_architecture.asciidoc)
*  [Payment Channels](07_payment_channels.asciidoc)
*  [Routing on a Network of Payment Channels](08_routing_htlcs.asciidoc)
*  [Channel Operation and Payment Forwarding](09_channel_operation.asciidoc)
*  [Onion Routing](10_onion_routing.asciidoc)
*  [Gossip and the Channel Graph](11_gossip_channel_graph.asciidoc)
*  [Pathfinding and Payment Delivery](12_path_finding.asciidoc)
*  [Wire Protocol: Framing and Extensibility](13_wire_protocol.asciidoc)
*  [Lightning's Encrypted Message Transport](14_encrypted_transport.asciidoc)
*  [Lightning Payment Requests](15_payment_requests.asciidoc)
*  [Security and Privacy of the Lightning Network](16_security_privacy_ln.asciidoc)
*  [Conclusion](17_conclusion.asciidoc)

### Appendices

*  [Bitcoin Fundamentals Review](appendix_bitcoin_fundamentals_review.asciidoc)
*  [Docker Basics](appendix_docker_basics.asciidoc)
*  [Protocol Messages](appendix_protocol_messages.asciidoc)

### Glossary

*  [Glossary](glossary.asciidoc)

### Author Bios and Colophon

*  [Author Bios](author_bio.html)
*  [Colophon](colo.html)

## Source and license

Mastering the Lightning Network is released under the Creative Commons CC-BY-NC-ND license, which allows sharing the source code for personal use only. You may read this book for free. You may not create derivatives (such as PDF copies), or distribute the book commercially. The full terms of the license can be found here:

[![Creative Commons License](https://i.creativecommons.org/l/by-nc-nd/4.0/88x31.png)](https://creativecommons.org/licenses/by-nc-nd/4.0/)

<span xmlns:dct="http://purl.org/dc/terms/" property="dct:title">Mastering the Lightning Network</span> by <a xmlns:cc="http://creativecommons.org/ns#" href="https://lnbook.info/" property="cc:attributionName" rel="cc:attributionURL">Andreas M. Antonopoulos, Olaoluwa Osuntokun, Rene Pickhardt</a> is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/">Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International License</a>.

## Translations and Derivatives (eg. PDF, HTML, EPUB ebooks)

The current license does **not permit derivative or commercial work**. This means, it does **not** permit independent translations without pemission/license from O'Reilly Media (publisher). It also does not permit the production and circulation of PDF, HTML or other derivative renderings of the source ASCIIDOC, (with the exception for personal use only, not shared with others).

You can't translate this book without permission. You can't create ebooks in PDF, HTML EPUB or any other format unless it is for personal use only and not shared/distributed.

## Licensing change in 12 months

It is expected that the book will be released under a more permissive CC-BY-SA license within a year of publication (i.e. Jan 2023). At that time we will provide a Transifex project for volunteer translations and it will be allowed to produce and share PDF or other ebook versions of the book.
